==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Befejez</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Tengely menti kötés...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>tengely menti kötést hoz létre két tárgy között</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Ön-teszt...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Fut egy önteszt, hogy ellenőrizze, ha az alkalmazás megfelelően működik</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>R&amp;ajzolás</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>S&amp;kicc</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>Sugá&amp;riánynyomvonal</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>Vázlatkészítés &amp;D</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Vázlat alap</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitívek</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Változós</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Az objektum megjelenése</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Vonal eszköztár</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Befejez</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Tengely menti kötés...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>tengely menti kötést hoz létre két tárgy között</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Ön-teszt...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Fut egy önteszt, hogy ellenőrizze, ha az alkalmazás megfelelően működik</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>R&amp;ajzolás</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>S&amp;kicc</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>Sugá&amp;riánynyomvonal</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>Vázlatkészítés &amp;D</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Vázlat alap</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitívek</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Változós</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Az objektum megjelenése</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Vonal eszköztár</translation>
    </message>
  </context>
</TS>
